package cn.com.infosec.asn1.isismtt.ocsp;

import cn.com.infosec.asn1.ASN1Choice;
import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1OctetString;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DEROctetString;
import cn.com.infosec.asn1.DERTaggedObject;
import cn.com.infosec.asn1.x509.X509CertificateStructure;
import java.io.IOException;

public class RequestedCertificate extends ASN1Encodable implements ASN1Choice {
   public static final int certificate = -1;
   public static final int publicKeyCertificate = 0;
   public static final int attributeCertificate = 1;
   private X509CertificateStructure cert;
   private byte[] publicKeyCert;
   private byte[] attributeCert;

   public static RequestedCertificate getInstance(Object obj) {
      if (obj != null && !(obj instanceof RequestedCertificate)) {
         if (obj instanceof ASN1Sequence) {
            return new RequestedCertificate(X509CertificateStructure.getInstance(obj));
         } else if (obj instanceof ASN1TaggedObject) {
            return new RequestedCertificate((ASN1TaggedObject)obj);
         } else {
            throw new IllegalArgumentException("illegal object in getInstance: " + obj.getClass().getName());
         }
      } else {
         return (RequestedCertificate)obj;
      }
   }

   public static RequestedCertificate getInstance(ASN1TaggedObject obj, boolean explicit) {
      if (explicit) {
         return getInstance(obj.getObject());
      } else {
         throw new IllegalArgumentException("choice item must be explicitly tagged");
      }
   }

   private RequestedCertificate(ASN1TaggedObject tagged) {
      if (tagged.getTagNo() == 0) {
         this.publicKeyCert = ASN1OctetString.getInstance(tagged, true).getOctets();
      } else {
         if (tagged.getTagNo() != 1) {
            throw new IllegalArgumentException("unknown tag number: " + tagged.getTagNo());
         }

         this.attributeCert = ASN1OctetString.getInstance(tagged, true).getOctets();
      }

   }

   public RequestedCertificate(X509CertificateStructure certificate) {
      this.cert = certificate;
   }

   public RequestedCertificate(int type, byte[] certificateOctets) {
      RequestedCertificate var10000 = this;
      DERTaggedObject var4;
      DERTaggedObject var10001 = var4 = new DERTaggedObject;
      DEROctetString var3;
      var3 = new DEROctetString.<init>(certificateOctets);
      var10001.<init>(type, var3);
      var10000.<init>((ASN1TaggedObject)var4);
   }

   public int getType() {
      if (this.cert != null) {
         return -1;
      } else {
         return this.publicKeyCert != null ? 0 : 1;
      }
   }

   public byte[] getCertificateBytes() {
      X509CertificateStructure var1;
      if ((var1 = this.cert) != null) {
         try {
            return var1.getEncoded();
         } catch (IOException var2) {
            throw new IllegalStateException("can't decode certificate: " + var2);
         }
      } else {
         byte[] var3;
         return (var3 = this.publicKeyCert) != null ? var3 : this.attributeCert;
      }
   }

   public DERObject toASN1Object() {
      byte[] var1;
      DEROctetString var2;
      if ((var1 = this.publicKeyCert) != null) {
         var2 = new DEROctetString.<init>(var1);
         return new DERTaggedObject(0, var2);
      } else if ((var1 = this.attributeCert) != null) {
         var2 = new DEROctetString.<init>(var1);
         return new DERTaggedObject(1, var2);
      } else {
         return this.cert.getDERObject();
      }
   }
}
